# Приложение для создания exe файла из .py

Приложение позволяет создать оконное приложение в одном файле и добавить в иконку. 

## Скачать
```bash
pip install icreate-exe
```

## Использование

```bash
icreate-exe [-h] [-i] name_file
```

1. **-h**: Выведет справочную информацию

2. **-i**: Путь до иконки
4. **name_file**: путь до файла .py

## Пример использования
<video width="320" height="240" controls>
    <source src="./video.mp4" type="video/mp4">
    Ваш браузер не поддерживает видео. 
</video>

Смотреть пример использования можно по <a href='https://drive.google.com/file/d/11qmZz5eXj-iMSqd1KVfKQqDbOq9S0HqH/view?usp=sharing'>ссылке</a>
